### Name: MCMCglmm
### Title: Multivariate Generalised Linear Mixed Models
### Aliases: MCMCglmm
### Keywords: models

### ** Examples


# Example 1: univariate gaussian model with standard random effect
 
data(PlodiaPO)  
model1<-MCMCglmm(PO~1, random=~FSfamily, data=PlodiaPO, verbose=FALSE)
plot(model1$VCV)

# Example 2: univariate gaussian model with phylogenetically correlated random effect

data(bird.families) 

phylo.effect<-rbv(bird.families, 1, nodes="TIPS") # simulate phylogenetic effects with unit variance
phenotype<-phylo.effect+rnorm(dim(phylo.effect)[1], 0, 1)  # add residual with unit variance

test.data<-data.frame(phenotype=phenotype, animal=as.factor(row.names(phenotype)))

model2<-MCMCglmm(phenotype~1, random=~animal, data=test.data, pedigree=bird.families, verbose=FALSE)
plot(model2$VCV)




